function [we,NEF,GEF,BEF] = elemtr3dp(PosABC)
%
% caracteristiques elementaires de l'element triangulaire a trois noeuds
%
% Pos = [x; y]
% NEF = [NI,NJ,Nk]
% [Epsxx; Epsyy; Epsxy] = BEF * [uAx; uAy; uBx; uBy; uCx; uCy]
% [Grad(T)x; Grad(T)y] = GEF * [TA; TB; TC]
% 

PosA = [PosABC(1,:)';0];
PosB = [PosABC(2,:)';0];
PosC = [PosABC(3,:)';0];

ex = [1,0,0];
ey = [0,1,0];
ez = [0,0,1];

% orientation de l'lment
Se = ez*cross(PosB-PosA,PosC-PosA)/2;
we = abs(Se);
if Se > 0
	PosI = PosA;
	PosJ = PosB;
	PosK = PosC;
    Renum = [1,2,3];
else
	PosI = PosA;
	PosJ = PosC;
	PosK = PosB;
    Renum = [1,3,2];
end

PosP = (PosI + PosJ + PosK)/3;

NI = 0.5*ez*cross(PosP-PosK,PosJ-PosK)/abs(Se);
NJ = 0.5*ez*cross(PosP-PosI,PosK-PosI)/abs(Se);
NK = 0.5*ez*cross(PosJ-PosI,PosP-PosI)/abs(Se);

% derivees

dNIdx = 0.5*ez*cross(ex',PosJ-PosK)/abs(Se);
dNIdy = 0.5*ez*cross(ey',PosJ-PosK)/abs(Se);

dNJdx = 0.5*ez*cross(ex',PosK-PosI)/abs(Se);
dNJdy = 0.5*ez*cross(ey',PosK-PosI)/abs(Se);

dNKdx = 0.5*ez*cross(PosJ-PosI,ex')/abs(Se);
dNKdy = 0.5*ez*cross(PosJ-PosI,ey')/abs(Se);

  NEF = [NI,     NJ,     NK];
  BEF = [dNIdx,  0,      dNJdx,  0,      dNKdx,  0;...
         0,      dNIdy,  0,      dNJdy,  0,      dNKdy;...
	     dNIdy/2,dNIdx/2,dNJdy/2,dNJdx/2,dNKdy/2,dNKdx/2];
	   
  GEF = [dNIdx,dNJdx,dNKdx;...
       dNIdy,dNJdy,dNKdy];
   
if Se < 0
   NEF = NEF(Renum);
   BEFo = BEF;
   BEF(:,2*[1,2,3])   = BEFo(:,2*Renum);
   BEF(:,2*[1,2,3]-1) = BEFo(:,2*Renum-1);
  
   GEF = GEF(:,Renum);  	   
 end

